@@ -7,7 +7,6 @@
 from . import *
 from .labelmanager import LabelManager
 
-from threading import Timer
 import json
 import os
 import subprocess
@@ -20,7 +19,7 @@ gi.require_version('Pango', '1.0')
 from gi.repository import GLib
 GLib.threads_init()
 
-from gi.repository import Gtk, Gdk, Pango
+from gi.repository import Gtk, Gdk, Pango, GObject
 import cairo
 
 
@@ -51,10 +50,12 @@ class Screenkey(Gtk.Window):
     def __init__(self, logger, options, show_settings=False):
         Gtk.Window.__init__(self, Gtk.WindowType.POPUP)
 
+        self.logger = logger
+        self.logger.debug("{} {}".format(APP_NAME, VERSION))
+
         self.exit_status = None
         self.timer_hide = None
         self.timer_min = None
-        self.logger = logger
 
         defaults = Options({'no_systray': False,
                             'timeout': 2.5,
@@ -76,7 +77,8 @@ class Screenkey(Gtk.Window):
                             'vis_shift': False,
                             'vis_space': True,
                             'geometry': None,
-                            'screen': 0})
+                            'screen': 0,
+                            'start_disabled': False})
         self.options = self.load_state()
         if self.options is None:
             self.options = defaults
@@ -306,27 +308,29 @@ class Screenkey(Gtk.Window):
 
         if not self.get_property('visible'):
             self.show()
-        if self.timer_hide:
-            self.timer_hide.cancel()
+        if self.timer_hide is not None:
+            GObject.source_remove(self.timer_hide)
         if self.options.timeout > 0:
-            self.timer_hide = Timer(self.options.timeout, self.on_timeout_main)
-            self.timer_hide.start()
-        if self.timer_min:
-            self.timer_min.cancel()
+            self.timer_hide = GObject.timeout_add(self.options.timeout * 1000, self.on_timeout_main)
+        if self.timer_min is not None:
+            GObject.source_remove(self.timer_min)
         if not synthetic:
-            self.timer_min = Timer(self.options.recent_thr * 2, self.on_timeout_min)
-            self.timer_min.start()
+            self.timer_min = GObject.timeout_add(self.options.recent_thr * 2000, self.on_timeout_min)
 
 
     def on_timeout_main(self):
         if not self.options.persist:
             self.hide()
+        self.timer_hide = None
         self.label.set_text('')
         self.labelmngr.clear()
+        return False
 
 
     def on_timeout_min(self):
+        self.timer_min = None
         self.labelmngr.queue_update()
+        return False
 
 
     def restart_labelmanager(self):
@@ -344,7 +348,8 @@ class Screenkey(Gtk.Window):
                                       recent_thr=self.options.recent_thr,
                                       compr_cnt=self.options.compr_cnt,
                                       ignore=self.options.ignore,
-                                      pango_ctx=self.label.get_pango_context())
+                                      pango_ctx=self.label.get_pango_context(),
+                                      enabled=not self.options.start_disabled)
         self.labelmngr.start()
 
 
@@ -677,10 +682,10 @@ class Screenkey(Gtk.Window):
         chk_compr.connect("toggled", on_cbox_compr_changed)
         self.sb_compr = Gtk.SpinButton(digits=0,
                                        numeric=True,
-                                       update_policy=IF_VALID,
-                                       value=self.options.compr_cnt or 3)
+                                       update_policy=IF_VALID)
         self.sb_compr.set_increments(1, 1)
         self.sb_compr.set_range(1, 100)
+        self.sb_compr.set_value(self.options.compr_cnt or 3)
         self.sb_compr.connect("value-changed", on_sb_compr_changed)
         hbox_compr.add(chk_compr)
         hbox_compr.add(self.sb_compr)
